@@ -22,10 +22,11 @@ import unittest2
 from stalker import (Asset, Entity, Link, Project, Repository, Scene, Sequence,
                      Shot, Status, StatusList, Task, Type, ImageFormat)
 
+
 class ShotTester(unittest2.TestCase):
     """Tests the Shot class
     """
-    
+
     def setUp(self):
         """setup the test
         """
@@ -42,7 +43,7 @@ class ShotTester(unittest2.TestCase):
             name="Waiting To Start",
             code="WTS"
         )
-        
+
         # status lists
         self.test_project_status_list = StatusList(
             name="Project Status List",
@@ -100,7 +101,7 @@ class ShotTester(unittest2.TestCase):
             name="Test Repository",
             type=self.test_repository_type,
         )
-        
+
         # image format
         self.test_image_format1 = ImageFormat(
             name='Test Image Format 1',
@@ -108,14 +109,14 @@ class ShotTester(unittest2.TestCase):
             height=1080,
             pixel_aspect=1.0
         )
-        
+
         self.test_image_format2 = ImageFormat(
             name='Test Image Format 2',
             width=1280,
             height=720,
             pixel_aspect=1.0
         )
-        
+
         # project and sequences
         self.test_project1 = Project(
             name='Test Project1',
@@ -125,7 +126,7 @@ class ShotTester(unittest2.TestCase):
             repository=self.test_repository,
             image_format=self.test_image_format1
         )
-        
+
         self.test_project2 = Project(
             name='Test Project2',
             code='tp2',
@@ -134,7 +135,7 @@ class ShotTester(unittest2.TestCase):
             repository=self.test_repository,
             image_format=self.test_image_format1
         )
-        
+
         self.test_sequence1 = Sequence(
             name="Test Seq1",
             code='ts1',
@@ -155,25 +156,25 @@ class ShotTester(unittest2.TestCase):
             project=self.test_project1,
             status_list=self.test_sequence_status_list,
         )
-        
+
         self.test_scene1 = Scene(
             name='Test Sce1',
             code='tsc1',
             project=self.test_project1,
         )
-        
+
         self.test_scene2 = Scene(
             name='Test Sce2',
             code='tsc2',
             project=self.test_project1,
         )
-        
+
         self.test_scene3 = Scene(
             name='Test Sce3',
             code='tsc3',
             project=self.test_project1
         )
-        
+
         self.test_asset1 = Asset(
             name="Test Asset1",
             code='ta1',
@@ -219,27 +220,27 @@ class ShotTester(unittest2.TestCase):
 
         # create a mock shot object
         self.test_shot = Shot(**self.kwargs)
-    
+
     def test___auto_name__class_attribute_is_set_to_True(self):
         """testing if the __auto_name__ class attribute is set to True for Shot
         class
         """
         self.assertTrue(Shot.__auto_name__)
-    
+
     def test_project_argument_is_skipped(self):
         """testing if a TypeError will be raised when the project argument is
         skipped
         """
         self.kwargs.pop('project')
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_project_argument_is_None(self):
         """testing if a TypeError will be raised when the project argument is
         None
         """
         self.kwargs["project"] = None
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_project_argument_is_not_Project_instance(self):
         """testing if a TypeError will be raised when the given sequence
         argument is not a Project instance
@@ -248,7 +249,7 @@ class ShotTester(unittest2.TestCase):
         for test_value in test_values:
             self.kwargs["project"] = test_value
             self.assertRaises(TypeError, Shot, self.kwargs)
-    
+
     def test_project_argument_already_has_a_shot_with_the_same_code(self):
         """testing if a ValueError will be raised when the given project
         argument already has a shot with the same code
@@ -257,17 +258,18 @@ class ShotTester(unittest2.TestCase):
         # with the same code
         self.kwargs['project'] = self.test_project1
         self.assertRaises(ValueError, Shot, **self.kwargs)
-        
+
         # this should not raise a ValueError
         self.kwargs["code"] = "DifferentCode"
         new_shot2 = Shot(**self.kwargs)
+        self.assertIsInstance(new_shot2, Shot)
 
     def test_project_attribute_is_read_only(self):
         """testing if the project attribute is read only
         """
-        self.assertRaises(AttributeError, setattr,self.test_shot, "project",
+        self.assertRaises(AttributeError, setattr, self.test_shot, "project",
                           self.test_project2)
-    
+
     def test_project_contains_shots(self):
         """testing if the current shot is going to be added to the Project, so
         the Project.shots list will contain the current shot
@@ -278,125 +280,6 @@ class ShotTester(unittest2.TestCase):
         """testing if the project argument is working properly
         """
         self.assertEqual(self.test_shot.project, self.kwargs["project"])
-    
-    def test_sequences_argument_is_skipped(self):
-        """testing if the sequences attribute will be an empty list when the
-        sequences argument is skipped
-        """
-        self.kwargs.pop('sequences')
-        self.kwargs['code'] = 'DifferentCode'
-        new_shot = Shot(**self.kwargs)
-        self.assertEqual(new_shot.sequences, [])
-    
-    def test_sequences_argument_is_None(self):
-        """testing if the sequences attribute will be an empty list when the
-        sequences argument is set to None
-        """
-        self.kwargs['sequences'] = None
-        self.kwargs['code'] = 'NewCode'
-        new_shot = Shot(**self.kwargs)
-        self.assertEqual(new_shot.sequences, [])
-    
-    def test_sequences_attribute_is_set_to_None(self):
-        """testing if a TypeError will be raised when the sequences attribute
-        is set to None
-        """
-        self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
-                          None)
-    
-    def test_sequences_argument_is_not_a_list(self):
-        """testing if a TypeError will be raised when the sequences argument is
-        not a list
-        """
-        self.kwargs['sequences'] = 'not a list'
-        self.kwargs['code'] = 'NewCode'
-        self.assertRaises(TypeError, Shot, **self.kwargs)
-    
-    def test_sequences_attribute_is_not_a_list(self):
-        """testing if a TypeError will be raised when the sequences attribute
-        is not a list
-        """
-        self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
-                          'not a list')
-    
-    def test_sequences_argument_is_not_a_list_of_Sequence_instances(self):
-        """testing if a TypeError will be raised when the sequences argument is
-        not a list of Sequences
-        """
-        self.kwargs['sequences'] = ['not', 1, 'list', 'of', 'sequences']
-        self.kwargs['code'] = 'NewShot'
-        self.assertRaises(TypeError, Shot, **self.kwargs)
-    
-    def test_sequences_attribute_is_not_a_list_of_Sequence_instances(self):
-        """testing if a TypeError will be raised when the sequences attribute
-        is not a list of Sequence instances
-        """
-        self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
-                          ['not', 1, 'list', 'of', 'sequences'])
-    
-    def test_sequences_argument_is_working_properly(self):
-        """testing if the sequences attribute is working properly
-        """
-        self.kwargs['code'] = 'NewShot'
-        
-        seq1 = Sequence(
-            name='seq1',
-            code='seq1',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        seq2 = Sequence(
-            name='seq2',
-            code='seq2',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        seq3 = Sequence(
-            name='seq3',
-            code='seq3',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        
-        seqs = [seq1, seq2, seq3]
-        self.kwargs['sequences'] = seqs
-        new_shot = Shot(**self.kwargs)
-        
-        self.assertItemsEqual(new_shot.sequences, seqs)
-    
-    def test_sequences_attribute_is_working_properly(self):
-        """testing if the sequences attribute is working properly
-        """
-        self.kwargs['code'] = 'NewShot'
-        
-        seq1 = Sequence(
-            name='seq1',
-            code='seq1',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        seq2 = Sequence(
-            name='seq2',
-            code='seq2',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        seq3 = Sequence(
-            name='seq3',
-            code='seq3',
-            project=self.test_project1,
-            status_list=self.test_sequence_status_list
-        )
-        
-        new_shot = Shot(**self.kwargs)
-        
-        new_shot.sequences = [seq1]
-        new_shot.sequences.append(seq2)
-        new_shot.sequences.append(seq3)
-        
-        seqs = [seq1, seq2, seq3]
-        self.assertItemsEqual(new_shot.sequences, seqs)
-    
 
     def test_sequences_argument_is_skipped(self):
         """testing if the sequences attribute will be an empty list when the
@@ -406,7 +289,7 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['code'] = 'DifferentCode'
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.sequences, [])
-    
+
     def test_sequences_argument_is_None(self):
         """testing if the sequences attribute will be an empty list when the
         sequences argument is set to None
@@ -415,14 +298,14 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['code'] = 'NewCode'
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.sequences, [])
-    
+
     def test_sequences_attribute_is_set_to_None(self):
         """testing if a TypeError will be raised when the sequences attribute
         is set to None
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
                           None)
-    
+
     def test_sequences_argument_is_not_a_list(self):
         """testing if a TypeError will be raised when the sequences argument is
         not a list
@@ -430,14 +313,14 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['sequences'] = 'not a list'
         self.kwargs['code'] = 'NewCode'
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_sequences_attribute_is_not_a_list(self):
         """testing if a TypeError will be raised when the sequences attribute
         is not a list
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
                           'not a list')
-    
+
     def test_sequences_argument_is_not_a_list_of_Sequence_instances(self):
         """testing if a TypeError will be raised when the sequences argument is
         not a list of Sequences
@@ -445,19 +328,19 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['sequences'] = ['not', 1, 'list', 'of', 'sequences']
         self.kwargs['code'] = 'NewShot'
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_sequences_attribute_is_not_a_list_of_Sequence_instances(self):
         """testing if a TypeError will be raised when the sequences attribute
         is not a list of Sequence instances
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'sequences',
                           ['not', 1, 'list', 'of', 'sequences'])
-    
+
     def test_sequences_argument_is_working_properly(self):
         """testing if the sequences attribute is working properly
         """
         self.kwargs['code'] = 'NewShot'
-        
+
         seq1 = Sequence(
             name='seq1',
             code='seq1',
@@ -466,28 +349,28 @@ class ShotTester(unittest2.TestCase):
         )
         seq2 = Sequence(
             name='seq2',
-            code='seq1',
+            code='seq2',
             project=self.test_project1,
             status_list=self.test_sequence_status_list
         )
         seq3 = Sequence(
             name='seq3',
-            code='seq1',
+            code='seq3',
             project=self.test_project1,
             status_list=self.test_sequence_status_list
         )
-        
+
         seqs = [seq1, seq2, seq3]
         self.kwargs['sequences'] = seqs
         new_shot = Shot(**self.kwargs)
-        
+
         self.assertItemsEqual(new_shot.sequences, seqs)
-    
+
     def test_sequences_attribute_is_working_properly(self):
         """testing if the sequences attribute is working properly
         """
         self.kwargs['code'] = 'NewShot'
-        
+
         seq1 = Sequence(
             name='seq1',
             code='seq1',
@@ -496,26 +379,26 @@ class ShotTester(unittest2.TestCase):
         )
         seq2 = Sequence(
             name='seq2',
-            code='seq1',
+            code='seq2',
             project=self.test_project1,
             status_list=self.test_sequence_status_list
         )
         seq3 = Sequence(
             name='seq3',
-            code='seq1',
+            code='seq3',
             project=self.test_project1,
             status_list=self.test_sequence_status_list
         )
-        
+
         new_shot = Shot(**self.kwargs)
-        
+
         new_shot.sequences = [seq1]
         new_shot.sequences.append(seq2)
         new_shot.sequences.append(seq3)
-        
+
         seqs = [seq1, seq2, seq3]
         self.assertItemsEqual(new_shot.sequences, seqs)
-    
+
     def test_scenes_argument_is_skipped(self):
         """testing if the scenes attribute will be an empty list when the
         scenes argument is skipped
@@ -524,7 +407,7 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['code'] = 'DifferentCode'
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.scenes, [])
-    
+
     def test_scenes_argument_is_None(self):
         """testing if the scenes attribute will be an empty list when the
         scenes argument is set to None
@@ -533,14 +416,14 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['code'] = 'NewCode'
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.scenes, [])
-    
+
     def test_scenes_attribute_is_set_to_None(self):
         """testing if a TypeError will be raised when the scenes attribute
         is set to None
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'scenes',
                           None)
-    
+
     def test_scenes_argument_is_not_a_list(self):
         """testing if a TypeError will be raised when the scenes argument is
         not a list
@@ -548,14 +431,14 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['scenes'] = 'not a list'
         self.kwargs['code'] = 'NewCode'
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_scenes_attribute_is_not_a_list(self):
         """testing if a TypeError will be raised when the scenes attribute
         is not a list
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'scenes',
                           'not a list')
-    
+
     def test_scenes_argument_is_not_a_list_of_Scene_instances(self):
         """testing if a TypeError will be raised when the scenes argument is
         not a list of Scenes
@@ -563,47 +446,47 @@ class ShotTester(unittest2.TestCase):
         self.kwargs['scenes'] = ['not', 1, 'list', 'of', 'scenes']
         self.kwargs['code'] = 'NewShot'
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_scenes_attribute_is_not_a_list_of_Scene_instances(self):
         """testing if a TypeError will be raised when the scenes attribute
         is not a list of Scene instances
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'scenes',
                           ['not', 1, 'list', 'of', 'scenes'])
-    
+
     def test_scenes_argument_is_working_properly(self):
         """testing if the scenes attribute is working properly
         """
         self.kwargs['code'] = 'NewShot'
-        
+
         sce1 = Scene(name='sce1', code='sce1', project=self.test_project1)
         sce2 = Scene(name='sce2', code='sce2', project=self.test_project1)
         sce3 = Scene(name='sce3', code='sce3', project=self.test_project1)
-        
+
         seqs = [sce1, sce2, sce3]
         self.kwargs['scenes'] = seqs
         new_shot = Shot(**self.kwargs)
-        
+
         self.assertItemsEqual(new_shot.scenes, seqs)
-    
+
     def test_scenes_attribute_is_working_properly(self):
         """testing if the scenes attribute is working properly
         """
         self.kwargs['code'] = 'NewShot'
-        
+
         sce1 = Scene(name='sce1', code='sce1', project=self.test_project1)
         sce2 = Scene(name='sce2', code='sce2', project=self.test_project1)
         sce3 = Scene(name='sce3', code='sce3', project=self.test_project1)
-        
+
         new_shot = Shot(**self.kwargs)
-        
+
         new_shot.scenes = [sce1]
         new_shot.scenes.append(sce2)
         new_shot.scenes.append(sce3)
-        
+
         seqs = [sce1, sce2, sce3]
         self.assertItemsEqual(new_shot.scenes, seqs)
-    
+
     def test_cut_in_argument_is_skipped_defaults_to_default_value(self):
         """testing if the cut_in argument is skipped the cut_in argument will
         be set to the default value
@@ -687,7 +570,7 @@ class ShotTester(unittest2.TestCase):
         """
         self.test_shot.cut_out = None
         self.assertEqual(self.test_shot.cut_out,
-                         self.test_shot.cut_in +\
+                         self.test_shot.cut_in +
                          self.test_shot.cut_duration - 1)
 
     def test_cut_out_argument_is_not_integer(self):
@@ -736,8 +619,8 @@ class ShotTester(unittest2.TestCase):
         self.kwargs["code"] = "SH123A"
         self.kwargs.pop("cut_duration")
         new_shot = Shot(**self.kwargs)
-        self.assertEqual(new_shot.cut_duration, new_shot.cut_out -
-                                                new_shot.cut_in + 1)
+        self.assertEqual(new_shot.cut_duration,
+                         new_shot.cut_out - new_shot.cut_in + 1)
 
     def test_cut_duration_argument_is_None(self):
         """testing if the value of cut_duration will be calculated from the
@@ -746,8 +629,8 @@ class ShotTester(unittest2.TestCase):
         self.kwargs["code"] = "SH123A"
         self.kwargs["cut_duration"] = None
         new_shot = Shot(**self.kwargs)
-        self.assertEqual(new_shot.cut_duration, new_shot.cut_out -
-                                                new_shot.cut_in + 1)
+        self.assertEqual(new_shot.cut_duration,
+                         new_shot.cut_out - new_shot.cut_in + 1)
 
     def test_cut_duration_argument_is_not_instance_of_int(self):
         """testing if a TypeError will be raised when the cut_duration
@@ -776,7 +659,7 @@ class ShotTester(unittest2.TestCase):
         self.test_shot.cut_in = 1
         self.assertEqual(
             self.test_shot.cut_duration,
-            self.test_shot.cut_out - 
+            self.test_shot.cut_out -
             self.test_shot.cut_in + 1
         )
 
@@ -786,7 +669,7 @@ class ShotTester(unittest2.TestCase):
         """
         self.test_shot.cut_out = 1000
         self.assertEqual(self.test_shot.cut_duration,
-                         self.test_shot.cut_out -\
+                         self.test_shot.cut_out - \
                          self.test_shot.cut_in + 1)
 
     def test_cut_duration_attribute_changes_cut_out_attribute(self):
@@ -794,12 +677,12 @@ class ShotTester(unittest2.TestCase):
         cut_out value.
         """
         first_cut_out = self.test_shot.cut_out
-        self.test_shot.cut_in
         self.test_shot.cut_duration = 245
         self.assertNotEquals(self.test_shot.cut_out, first_cut_out)
-        self.assertEqual(self.test_shot.cut_out,
-                         self.test_shot.cut_in +\
-                         self.test_shot.cut_duration - 1)
+        self.assertEqual(
+            self.test_shot.cut_out,
+            self.test_shot.cut_in + self.test_shot.cut_duration - 1
+        )
 
     def test_cut_duration_attribute_is_zero(self):
         """testing if the cut_duration attribute will be set to 1 and the
@@ -869,7 +752,7 @@ class ShotTester(unittest2.TestCase):
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.cut_duration, 1)
         self.assertEqual(new_shot.cut_out, new_shot.cut_in)
-    
+
     def test_image_format_argument_is_skipped(self):
         """testing if the image_format is copied from the Project instance when
         the image_format argument is skipped
@@ -879,7 +762,7 @@ class ShotTester(unittest2.TestCase):
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.image_format,
                          self.kwargs['project'].image_format)
-    
+
     def test_image_format_argument_is_None(self):
         """testing if the image format is copied from the Project instance when
         the image_format argument is None
@@ -889,7 +772,7 @@ class ShotTester(unittest2.TestCase):
         new_shot = Shot(**self.kwargs)
         self.assertEqual(new_shot.image_format,
                          self.kwargs['project'].image_format)
-    
+
     def test_image_format_attribute_is_None(self):
         """testing if the image format is copied from the Project instance when
         the image_format attribute is set to None
@@ -900,28 +783,28 @@ class ShotTester(unittest2.TestCase):
         self.test_shot.image_format = None
         self.assertEqual(self.test_shot.image_format,
                          self.test_shot.project.image_format)
-    
+
     def test_image_format_argument_is_not_a_ImageFormat_instance_and_not_None(self):
         """testing if a TypeError will be raised when the image_format argument
         is not a ImageFormat instance and not None
         """
-        self.kwargs['code'] = 'newshot'
+        self.kwargs['code'] = 'new_shot'
         self.kwargs['image_format'] = 'not an image format instance'
         self.assertRaises(TypeError, Shot, **self.kwargs)
-    
+
     def test_image_format_attribute_is_not_a_ImageFormat_instance_and_not_None(self):
         """testing if a TypeError will be raised when the image_format
         attribute is not a ImageFormat instance and not None
         """
         self.assertRaises(TypeError, setattr, self.test_shot, 'not an image f')
-    
+
     def test_image_format_argument_is_working_properly(self):
         """testing if the image_format argument value is passed to the
         image_format attribute correctly
         """
         self.assertEqual(self.kwargs['image_format'],
                          self.test_shot.image_format)
-    
+
     def test_image_format_attribute_is_working_properly(self):
         """testing if the image_format attribute is working properly
         """
@@ -930,13 +813,13 @@ class ShotTester(unittest2.TestCase):
         self.test_shot.image_format = self.test_image_format1
         self.assertEqual(self.test_shot.image_format,
                          self.test_image_format1)
-    
+
     def test_equality(self):
         """testing equality of shot objects
         """
         self.kwargs["code"] = "SH123A"
         new_shot1 = Shot(**self.kwargs)
-        
+
         self.kwargs["project"] = self.test_project2
         new_shot2 = Shot(**self.kwargs)
         # an entity with the same parameters
@@ -957,18 +840,18 @@ class ShotTester(unittest2.TestCase):
         """
         self.kwargs['code'] = 'SH123A'
         new_shot1 = Shot(**self.kwargs)
-        
+
         self.kwargs['project'] = self.test_project2
         new_shot2 = Shot(**self.kwargs)
         # an entity with the same parameters
         # just set the name to the code too
         self.kwargs['name'] = self.kwargs['code']
         new_entity = Entity(**self.kwargs)
-        
+
         # another shot with different code
         self.kwargs['code'] = 'SHAnotherShot'
         new_shot3 = Shot(**self.kwargs)
-        
+
         self.assertTrue(new_shot1 != new_shot2)
         self.assertTrue(new_shot1 != new_entity)
         self.assertTrue(new_shot1 != new_shot3)
@@ -1044,7 +927,7 @@ class ShotTester(unittest2.TestCase):
             status_list=project_status_list,
             type=project_type,
             repository=self.test_repository,
-            )
+        )
 
         self.kwargs["code"] = "SH12314"
 
